Service

Struct Service 

pub struct Service { /* private fields */ }
A docker service.

Docker services are used to run tasks when Docker is configured to use a swarm.

This allows the swarm manager to schedule the task on available resources.

The service will always have a single replica of the task and the task will not restart.

Implementations

Source

impl Service

pub fn new( client: Docker, id: String, stdout: Option<PathBuf>, stderr: Option<PathBuf>, ) -> Self

Creates a new Service if you already know the id of the service.

You should typically use a Builder unless you receive the service name externally from a user (say, on the command line as an argument).

pub fn id(&self) -> &str

Gets the id of the service.

pub async fn run( &self, task_name: &str, events: Option<EventOptions>, ) -> Result<ExecutionResult>

Runs a service and waits for the task execution to end.

pub async fn delete(&self) -> Result<()>

Deletes a service.