pub struct Service { /* private fields */ }Expand description
A docker service.
Docker services are used to run tasks when Docker is configured to use a swarm.
This allows the swarm manager to schedule the task on available resources.
The service will always have a single replica of the task and the task will not restart.
Implementations